## What does this PR do?

<!-- Describe your changes in 1-2 sentences. -->

## Checklist

- [ ] Tests added/updated
- [ ] `ruff check` passes
- [ ] `ruff format` passes
- [ ] Type hints added to public APIs
